==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fblock_sender.2.01-1.2.8.tar.gz: block_sender/mysql.php <==
<?php
/*
   Block Sender - A Plugin for SqurrelMail
   Version: 2.01
   Version Date: 06-Jan-2003
   Author: Derek Battams <derek@battams.ca>
   Please see the README file for further information

   File: mysql.php

DATE          AUTHOR   CHANGE
=============================================================================
06-Jan-2003   ddb      Initial version
Contains common code for MySQL support.
*/

/* USERS OF THIS PLUGIN SHOULD MODIFY THE FOLLOWING THREE LINES TO MATCH THEIR SYSTEM SETUP */
define("BLOCK_HOST", "localhost"); // Host where the MySQL server is - use localhost if the server is local
define("BLOCK_ID", "smuser");      // MySQL user ID to use - shouldn't use root!
define("BLOCK_PWD", "smpwd");      // MySQL password

/*
   The following functions are basically the PHP equivalent of the C program that accompanies this package.
   The comments in the C code should sufficiently explain what's going on below, if you're interested.
*/
function isBlocked($sender)
{
   $domain = "*" . substr($sender, strpos($sender, "@"));

   if(chkDatabase(BLOCK_HOST, BLOCK_ID, BLOCK_PWD, $domain))
      return true;
   if(chkDatabase(BLOCK_HOST, BLOCK_ID, BLOCK_PWD, $sender))
      return true;
   return false;
}   

function chkDatabase($host, $id, $pwd, $key)
{
   if(!($db = mysql_connect($host, $id, $pwd)))
      return false;
   if(!mysql_select_db("squirrelmail", $db))
   {
      mysql_close($db);
      return false;
   }

   if(!is_array($_SESSION))
      global $_SESSION;
   $user = mysql_escape_string($_SESSION["username"]);
   $key = mysql_escape_string($key);

   $qry = "SELECT user FROM blocked WHERE user='$user' AND email='$key'";
   $result = mysql_query($qry, $db);

   if(!$result || !mysql_num_rows($result))
      $retVal = false;
   else
      $retVal = true;
   mysql_free_result($result);
   mysql_close($db); 
   return $retVal;
}

function addRecord($key)
{
   if(!($db = mysql_connect(BLOCK_HOST, BLOCK_ID, BLOCK_PWD)))
      return false;
   if(!mysql_select_db("squirrelmail", $db))
   {
      mysql_close($db);
      return false;
   }

   if(!is_array($_SESSION))
      global $_SESSION;
   $user = mysql_escape_string($_SESSION["username"]);
   $key = mysql_escape_string($key);

   $qry = "INSERT INTO blocked (user, email) VALUES ('$user', '$key')";
   $result = mysql_query($qry, $db);

   if(!$result)
      $retVal = false;
   else
      $retVal = true;

   mysql_free_result($result);
   mysql_close($db);
   return $retVal;
}
?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fblock_sender.2.02-1.4.0.tar.gz: block_sender/mysql.php <==
<?php
/*
   Block Sender - A Plugin for SqurrelMail
   Version: 2.02
   Version Date: 16-May-2003
   Author: Derek Battams <derek@battams.ca>
   Please see the README file for further information

   File: mysql.php

DATE          AUTHOR   CHANGE
=============================================================================
06-Jan-2003   ddb      Initial version
30-Jan-2003   ddb      Corrected bug in addRecord() (removed free result call)

Contains common code for MySQL support.
*/

/* USERS OF THIS PLUGIN SHOULD MODIFY THE FOLLOWING THREE LINES TO MATCH THEIR SYSTEM SETUP */
define("BLOCK_HOST", "localhost"); // Host where the MySQL server is - use localhost if the server is local
define("BLOCK_ID", "sm");      // MySQL user ID to use - shouldn't use root!
define("BLOCK_PWD", "password");      // MySQL password

/*
   The following functions are basically the PHP equivalent of the C program that accompanies this package.
   The comments in the C code should sufficiently explain what's going on below, if you're interested.
*/
function isBlocked($sender)
{
   $domain = "*" . substr($sender, strpos($sender, "@"));

   if(chkDatabase(BLOCK_HOST, BLOCK_ID, BLOCK_PWD, $domain))
      return true;
   if(chkDatabase(BLOCK_HOST, BLOCK_ID, BLOCK_PWD, $sender))
      return true;
   return false;
}   

function chkDatabase($host, $id, $pwd, $key)
{
   if(!($db = mysql_connect($host, $id, $pwd)))
      return false;
   if(!mysql_select_db("squirrelmail", $db))
   {
      mysql_close($db);
      return false;
   }

   if(!is_array($_SESSION))
      global $_SESSION;
   $user = mysql_escape_string($_SESSION["username"]);
   $key = mysql_escape_string($key);

   $qry = "SELECT user FROM blocked WHERE user='$user' AND email='$key'";
   $result = mysql_query($qry, $db);

   if(!$result || !mysql_num_rows($result))
      $retVal = false;
   else
      $retVal = true;
   mysql_free_result($result);
   mysql_close($db); 
   return $retVal;
}

function addRecord($key)
{
   if(!($db = mysql_connect(BLOCK_HOST, BLOCK_ID, BLOCK_PWD)))
      return false;
   if(!mysql_select_db("squirrelmail", $db))
   {
      mysql_close($db);
      return false;
   }

   if(!is_array($_SESSION))
      global $_SESSION;
   $user = mysql_escape_string($_SESSION["username"]);
   $key = mysql_escape_string($key);

   $qry = "INSERT INTO blocked (user, email) VALUES ('$user', '$key')";
   $result = mysql_query($qry, $db);

   if(!$result)
      $retVal = false;
   else
      $retVal = true;

   mysql_close($db);
   return $retVal;
}
?>
